@@ -1,5 +1,6 @@
+import matplotlib.pyplot as pp
 import pycbc.psd
-import pylab
+
 
 # List the available analytic psds
 print(pycbc.psd.get_lalsim_psd_list())
@@ -14,7 +15,7 @@ p1 = pycbc.psd.aLIGOZeroDetHighPower(flen, delta_f, low_frequency_cutoff)
 # or by using the name as a string.
 p2 = pycbc.psd.from_string('aLIGOZeroDetLowPower', flen, delta_f, low_frequency_cutoff)
 
-pylab.plot(p1.sample_frequencies, p1, label='HighPower')
-pylab.plot(p2.sample_frequencies, p2, label='LowPower')
-pylab.legend()
-pylab.show()
+pp.plot(p1.sample_frequencies, p1, label='HighPower')
+pp.plot(p2.sample_frequencies, p2, label='LowPower')
+pp.legend()
+pp.show()
