@@ -17,8 +17,6 @@
 """I/O utilities for pycbc inference
 """
 
-from __future__ import absolute_import
-from __future__ import print_function
 
 import os
 import argparse
@@ -703,7 +701,6 @@ def results_from_cli(opts, load_samples=True, **kwargs):
             # read samples from file
             samples = fp.samples_from_cli(opts, parameters=opts.parameters,
                                           **kwargs)
-
             logging.info("Loaded {} samples".format(samples.size))
 
             if input_file in constraints:
