@@ -53,8 +53,6 @@ class BaseGatedGaussian(BaseGaussianNoise):
         self._overwhitened_data = {}
         # cache the current gated data
         self._gated_data = {}
-        # attribute for storing the current waveforms
-        self._current_wfs = None
         # highpass waveforms with the given frequency
         self.highpass_waveforms = highpass_waveforms
         if self.highpass_waveforms:
@@ -79,12 +77,6 @@ class BaseGatedGaussian(BaseGaussianNoise):
                                    data=data, psds=psds,
                                    **kwargs)
 
-    def update(self, **params):
-        # update
-        super().update(**params)
-        # reset current waveforms
-        self._current_wfs = None
-
     @BaseDataModel.data.setter
     def data(self, data):
         """Store a copy of the FD and TD data."""
@@ -447,41 +439,44 @@ class BaseGatedGaussian(BaseGaussianNoise):
             opts.low_frequency_cutoff = lfs
         return out
 
-    def write_metadata(self, fp):
-        """Adds writing the psds.
+    def write_metadata(self, fp, group=None):
+        """Adds writing the psds, and analyzed detectors.
 
         The analyzed detectors, their analysis segments, and the segments
-        used for psd estimation are written to the file's ``attrs``, as
+        used for psd estimation are written as
         ``analyzed_detectors``, ``{{detector}}_analysis_segment``, and
-        ``{{detector}}_psd_segment``, respectively.
+        ``{{detector}}_psd_segment``, respectively. These are either written
+        to the specified ``group``'s attrs, or to the top level attrs if
+        ``group`` is None.
 
         Parameters
         ----------
         fp : pycbc.inference.io.BaseInferenceFile instance
             The inference file to write to.
+        group : str, optional
+            If provided, the metadata will be written to the attrs specified
+            by group, i.e., to ``fp[group].attrs``. Otherwise, metadata is
+            written to the top-level attrs (``fp.attrs``).
         """
         BaseDataModel.write_metadata(self, fp)
+        attrs = fp.getattrs(group=group)
         # write the analyzed detectors and times
-        fp.attrs['analyzed_detectors'] = self.detectors
+        attrs['analyzed_detectors'] = self.detectors
         for det, data in self.data.items():
             key = '{}_analysis_segment'.format(det)
-            fp.attrs[key] = [float(data.start_time), float(data.end_time)]
-        if self._psds is not None:
-            fp.write_psd(self._psds)
+            attrs[key] = [float(data.start_time), float(data.end_time)]
+        if self._psds is not None and not self.no_save_data:
+            fp.write_psd(self._psds, group=group)
         # write the times used for psd estimation (if they were provided)
         for det in self.psd_segments:
             key = '{}_psd_segment'.format(det)
-            fp.attrs[key] = list(map(float, self.psd_segments[det]))
-        # write frequency cutoffs
+            attrs[key] = list(map(float, self.psd_segments[det]))
+        # save the frequency cutoffs
         for det in self.detectors:
-            # Save each IFO's low frequency cutoff used in the likelihood
-            # computation as an attribute
-            fp.attrs['{}_likelihood_low_freq'.format(det)] = self._f_lower[det]
-            # Save the IFO's high frequency cutoff used in the likelihood
-            # computation as an attribute if one was provided the user
+            attrs['{}_likelihood_low_freq'.format(det)] = self._f_lower[det]
             if self._f_upper[det] is not None:
-                fp.attrs['{}_likelihood_high_freq'.format(det)] = \
-                                                        self._f_upper[det]
+                attrs['{}_likelihood_high_freq'.format(det)] = \
+                    self._f_upper[det]
 
 
 class GatedGaussianNoise(BaseGatedGaussian):
