@@ -26,14 +26,10 @@ This modules provides classes and functions for using the dynesty sampler
 packages for parameter estimation.
 """
 
-
-from __future__ import absolute_import
-
 import logging
 import time
 import numpy
 import dynesty, dynesty.dynesty, dynesty.nestedsamplers
-from dynesty.utils import unitcheck, reflect
 from pycbc.pool import choose_pool
 from dynesty import utils as dyfunc
 from pycbc.inference.io import (DynestyFile, validate_checkpoint_files,
@@ -74,19 +70,25 @@ class DynestySampler(BaseSampler):
                  checkpoint_time_interval=None, maxcall=None,
                  loglikelihood_function=None, use_mpi=False,
                  no_save_state=False,
-                 run_kwds=None, **kwargs):
+                 run_kwds=None,
+                 extra_kwds=None,
+                 internal_kwds=None,
+                 **kwargs):
 
         self.model = model
         self.no_save_state = no_save_state
         log_likelihood_call, prior_call = setup_calls(
             model,
-            loglikelihood_function=loglikelihood_function)
+            loglikelihood_function=loglikelihood_function,
+            copy_prior=True)
         # Set up the pool
         self.pool = choose_pool(mpi=use_mpi, processes=nprocesses)
 
         self.maxcall = maxcall
         self.checkpoint_time_interval = checkpoint_time_interval
         self.run_kwds = {} if run_kwds is None else run_kwds
+        self.extra_kwds = {} if extra_kwds is None else extra_kwds
+        self.internal_kwds = {} if internal_kwds is None else internal_kwds
         self.nlive = nlive
         self.names = model.sampling_params
         self.ndim = len(model.sampling_params)
@@ -126,11 +128,11 @@ class DynestySampler(BaseSampler):
         if len(reflective) == 0:
             reflective = None
 
-        if 'sample' in kwargs:
-            if 'rwalk2' in kwargs['sample']:
+        if 'sample' in extra_kwds:
+            if 'rwalk2' in extra_kwds['sample']:
                 dynesty.dynesty._SAMPLING["rwalk"] = sample_rwalk_mod
                 dynesty.nestedsamplers._SAMPLING["rwalk"] = sample_rwalk_mod
-                kwargs['sample'] = 'rwalk'
+                extra_kwds['sample'] = 'rwalk'
 
         if self.nlive < 0:
             # Interpret a negative input value for the number of live points
@@ -141,7 +143,7 @@ class DynestySampler(BaseSampler):
                                                          pool=self.pool,
                                                          reflective=reflective,
                                                          periodic=periodic,
-                                                         **kwargs)
+                                                         **extra_kwds)
             self.run_with_checkpoint = False
             logging.info("Checkpointing not currently supported with"
                          "DYNAMIC nested sampler")
@@ -151,7 +153,8 @@ class DynestySampler(BaseSampler):
                                                   nlive=self.nlive,
                                                   reflective=reflective,
                                                   periodic=periodic,
-                                                  pool=self.pool, **kwargs)
+                                                  pool=self.pool, **extra_kwds)
+        self._sampler.kwargs.update(internal_kwds)
 
         # properties of the internal sampler which should not be pickled
         self.no_pickle = ['loglikelihood',
@@ -161,7 +164,8 @@ class DynestySampler(BaseSampler):
                           '_UPDATE', '_PROPOSE',
                           'evolve_point', 'use_pool', 'queue_size',
                           'use_pool_ptform', 'use_pool_logl',
-                          'use_pool_evolve']
+                          'use_pool_evolve', 'use_pool_update',
+                          'pool', 'M']
 
     def run(self):
         diff_niter = 1
@@ -288,23 +292,31 @@ class DynestySampler(BaseSampler):
 
         # optional arguments for dynesty
         cargs = {'bound': str,
-                 'maxcall': int,
                  'bootstrap': int,
                  'enlarge': float,
                  'update_interval': float,
                  'sample': str,
-                 'checkpoint_time_interval': float,
                  'first_update_min_ncall': int,
                  'first_update_min_eff': float,
                  'walks': int,
+                 }
+
+        # optional arguments that must be set internally
+        internal_args = {
                  'maxmcmc': int,
                  'nact': int,
                  }
+
         extra = {}
         run_extra = {}
-        for karg in cargs:
-            if cp.has_option(section, karg):
-                extra[karg] = cargs[karg](cp.get(section, karg))
+        internal_extra = {}
+        for args, argt in [(extra, cargs),
+                           (run_extra, rargs),
+                           (internal_extra, internal_args),
+                          ]:
+            for karg in argt:
+                if cp.has_option(section, karg):
+                    args[karg] = argt[karg](cp.get(section, karg))
 
         #This arg needs to be a dict
         first_update = {}
@@ -317,14 +329,23 @@ class DynestySampler(BaseSampler):
             logging.info('First update: min_eff:%s', first_update['min_eff'])
         extra['first_update'] = first_update
 
-        for karg in rargs:
-            if cp.has_option(section, karg):
-                run_extra[karg] = rargs[karg](cp.get(section, karg))
+        # populate options for checkpointing
+        checkpoint_time_interval = None
+        maxcall = None
+        if cp.has_option(section, 'checkpoint_time_interval'):
+            ck_time = float(cp.get(section, 'checkpoint_time_interval'))
+            checkpoint_time_interval = ck_time
+        if cp.has_option(section, 'maxcall'):
+            maxcall = int(cp.get(section, 'maxcall'))
 
         obj = cls(model, nlive=nlive, nprocesses=nprocesses,
                   loglikelihood_function=loglikelihood_function,
+                  checkpoint_time_interval=checkpoint_time_interval,
+                  maxcall=maxcall,
                   no_save_state=no_save_state,
-                  use_mpi=use_mpi, run_kwds=run_extra, **extra)
+                  use_mpi=use_mpi, run_kwds=run_extra,
+                  extra_kwds=extra,
+                  internal_kwds=internal_extra,)
         setup_output(obj, output_file, check_nsamples=False)
 
         if not obj.new_checkpoint:
@@ -376,11 +397,10 @@ class DynestySampler(BaseSampler):
         """Sets the state of the sampler back to the instance saved in a file.
         """
         with self.io(filename, 'r') as fp:
-            numpy.random.set_state(fp.read_random_state())
-
-        self._sampler.rstate = numpy.random
-        #if self.nlive < 0:
-        #    self._sampler.sampler.rstate = numpy.random
+            state = fp.read_random_state()
+            # Dynesty handles most randomeness through rstate which is
+            # pickled along with the class instance
+            numpy.random.set_state(state)
 
     def finalize(self):
         """Finalze and write it to the results file
@@ -465,10 +485,21 @@ def sample_rwalk_mod(args):
 
         Adapted from version used in bilby/dynesty
     """
+    try:
+        # dynesty <= 1.1
+        from dynesty.utils import unitcheck, reflect
+
+        # Unzipping.
+        (u, loglstar, axes, scale,
+        prior_transform, loglikelihood, kwargs) = args
+
+    except ImportError:
+        # dynest >= 1.2
+        from dynesty.utils import unitcheck, apply_reflect as reflect
+
+        (u, loglstar, axes, scale,
+        prior_transform, loglikelihood, _, kwargs) = args
 
-    # Unzipping.
-    (u, loglstar, axes, scale,
-     prior_transform, loglikelihood, kwargs) = args
     rstate = numpy.random
 
     # Bounds
@@ -515,6 +546,8 @@ def sample_rwalk_mod(args):
             u_prop[reflective] = reflect(u_prop[reflective])
 
         # Check unit cube constraints.
+        if u.max() < 0:
+            break
         if unitcheck(u_prop, nonbounded):
             pass
         else:
