@@ -30,12 +30,9 @@ import numpy as np
 import lal
 import copy
 import logging
-from six import add_metaclass
 from abc import ABCMeta, abstractmethod
-import lalsimulation as sim
 import h5py
-from pycbc import waveform
-from pycbc import frame
+from pycbc import waveform, frame, libutils
 from pycbc.opt import LimitedSizeDict
 from pycbc.waveform import get_td_waveform, utils as wfutils
 from pycbc.waveform import ringdown_td_approximants
@@ -47,13 +44,13 @@ import pycbc.io
 from pycbc.io.ligolw import LIGOLWContentHandler
 from ligo.lw import utils as ligolw_utils, ligolw, lsctables
 
+sim = libutils.import_optional('lalsimulation')
 
 injection_func_map = {
-    np.dtype(float32): sim.SimAddInjectionREAL4TimeSeries,
-    np.dtype(float64): sim.SimAddInjectionREAL8TimeSeries
+    np.dtype(float32): lambda *args: sim.SimAddInjectionREAL4TimeSeries(*args),
+    np.dtype(float64): lambda *args: sim.SimAddInjectionREAL8TimeSeries(*args),
 }
 
-
 # Map parameter names used in pycbc to names used in the sim_inspiral
 # table, if they are different
 sim_inspiral_map = {
@@ -72,6 +69,9 @@ def set_sim_data(inj, field, data):
     if sim_field == 'tc':
         inj.geocent_end_time = int(data)
         inj.geocent_end_time_ns = int(1e9*(data % 1))
+    # for spin1 and spin2 we need data to be an array
+    if sim_field in ['spin1', 'spin2']:
+        setattr(inj, sim_field, [0, 0, data])
     else:
         setattr(inj, sim_field, data)
 
@@ -333,8 +333,7 @@ class _XMLInjectionSet(object):
 # -----------------------------------------------------------------------------
 
 
-@add_metaclass(ABCMeta)
-class _HDFInjectionSet(object):
+class _HDFInjectionSet(metaclass=ABCMeta):
     """Manages sets of injections: reads injections from hdf files
     and injects them into time series.
 
@@ -356,6 +355,7 @@ class _HDFInjectionSet(object):
         Parameter names that must exist in the injection HDF file in order to
         create an injection of that type.
     """
+
     _tableclass = pycbc.io.FieldArray
     injtype = None
     required_params = ()
