@@ -7,12 +7,12 @@ import json
 from ligo.lw import ligolw
 from ligo.lw import lsctables
 from ligo.lw import utils as ligolw_utils
-from ligo.lw.utils import process as ligolw_process
 from ligo.lw.param import Param as LIGOLWParam
 from ligo.lw.array import Array as LIGOLWArray
 from pycbc import version as pycbc_version
 from pycbc import pnutils
-from pycbc.io.ligolw import return_empty_sngl
+from pycbc.io.ligolw import return_empty_sngl, create_process_table
+from pycbc.results import generate_asd_plot
 from pycbc.results import ifo_color
 from pycbc.results import source_color
 from pycbc.mchirp_area import calc_probabilities
@@ -142,13 +142,10 @@ class SingleCoincForGraceDB(object):
         outdoc = ligolw.Document()
         outdoc.appendChild(ligolw.LIGO_LW())
 
-        # ligo.lw does not like `cvs_entry_time` being an empty string
-        cvs_entry_time = pycbc_version.date or None
-        proc_id = ligolw_process.register_to_xmldoc(
-            outdoc, 'pycbc', {}, instruments=usable_ifos, comment='',
-            version=pycbc_version.version,
-            cvs_repository='pycbc/'+pycbc_version.git_branch,
-            cvs_entry_time=cvs_entry_time).process_id
+        # FIXME is it safe (in terms of downstream operations) to let
+        # `program_name` default to the actual script name?
+        proc_id = create_process_table(outdoc, program_name='pycbc',
+                                       detectors=usable_ifos).process_id
 
         # Set up coinc_definer table
         coinc_def_table = lsctables.New(lsctables.CoincDefTable)
@@ -326,68 +323,6 @@ class SingleCoincForGraceDB(object):
         # as GraceDB operations can fail later
         self.save(fname)
 
-        if self.snr_series is not None:
-            if fname.endswith('.xml.gz'):
-                snr_series_fname = fname.replace('.xml.gz', '.hdf')
-            else:
-                snr_series_fname = fname.replace('.xml', '.hdf')
-            snr_series_plot_fname = snr_series_fname.replace('.hdf',
-                                                             '_snr.png')
-            psd_series_plot_fname = snr_series_fname.replace('.hdf',
-                                                             '_psd.png')
-            pl.figure()
-            ref_time = int(self.merger_time)
-            for ifo in sorted(self.snr_series):
-                curr_snrs = self.snr_series[ifo]
-                curr_snrs.save(snr_series_fname, group='%s/snr' % ifo)
-                pl.plot(curr_snrs.sample_times - ref_time, abs(curr_snrs),
-                        c=ifo_color(ifo), label=ifo)
-                if ifo in self.ifos:
-                    base = 'foreground/{}/'.format(ifo)
-                    snr = self.coinc_results[base + 'snr']
-                    mt = (self.coinc_results[base + 'end_time']
-                          + self.time_offset)
-                    pl.plot([mt - ref_time], [snr], c=ifo_color(ifo),
-                            marker='x')
-
-            pl.legend()
-            pl.xlabel('GPS time from {:d} (s)'.format(ref_time))
-            pl.ylabel('SNR')
-            pl.savefig(snr_series_plot_fname)
-            pl.close()
-
-            pl.figure()
-            for ifo in sorted(self.snr_series):
-                # Undo dynamic range factor
-                curr_psd = self.psds[ifo].astype(numpy.float64)
-                curr_psd /= pycbc.DYN_RANGE_FAC ** 2.0
-                curr_psd.save(snr_series_fname, group='%s/psd' % ifo)
-                # Can't plot log(0) so start from point 1
-                pl.loglog(curr_psd.sample_frequencies[1:],
-                          curr_psd[1:]**0.5, c=ifo_color(ifo), label=ifo)
-            pl.legend()
-            pl.xlim([10, 1300])
-            pl.ylim([3E-24, 1E-20])
-            pl.xlabel('Frequency (Hz)')
-            pl.ylabel('ASD')
-            pl.savefig(psd_series_plot_fname)
-            pl.close()
-
-        if self.probabilities is not None:
-            prob_fname = fname.replace('.xml.gz', '_probs.json')
-            prob_plot_fname = prob_fname.replace('.json', '.png')
-
-            prob_plot = {k: v for (k, v) in self.probabilities.items()
-                         if v != 0.0}
-            labels, sizes = zip(*prob_plot.items())
-            colors = [source_color(label) for label in labels]
-            fig, ax = pl.subplots()
-            ax.pie(sizes, labels=labels, colors=colors, autopct='%1.1f%%',
-                   textprops={'fontsize': 15})
-            ax.axis('equal')
-            fig.savefig(prob_plot_fname)
-            pl.close()
-
         gid = None
         try:
             # try connecting to GraceDB
@@ -404,51 +339,116 @@ class SingleCoincForGraceDB(object):
                 gracedb.writeLabel(gid, 'INJ')
                 logging.info("Tagging event %s as an injection", gid)
 
-            # upload PSDs. Note that the PSDs are already stored in the
-            # original event file and we just upload a copy of that same file
-            # here. This keeps things as they were in O2 and can be removed
-            # after updating the follow-up infrastructure
-            psd_fname = 'psd.xml.gz' if fname.endswith('.gz') else 'psd.xml'
-            gracedb.writeLog(gid, "PyCBC PSD estimate from the time of event",
-                             psd_fname, open(fname, "rb").read(), "psd")
-            logging.info("Uploaded PSDs for event %s", gid)
-
             # add info for tracking code version
             gracedb_tag_with_version(gracedb, gid)
 
             extra_strings = [] if extra_strings is None else extra_strings
             for text in extra_strings:
                 gracedb.writeLog(gid, text, tag_name=['analyst_comments'])
-
-            # upload SNR series in HDF format and plots
-            if self.snr_series is not None:
-                gracedb.writeLog(gid, 'SNR timeseries HDF file upload',
-                                 filename=snr_series_fname)
-                gracedb.writeLog(gid, 'SNR timeseries plot upload',
-                                 filename=snr_series_plot_fname,
-                                 tag_name=['background'],
-                                 displayName=['SNR timeseries'])
-                gracedb.writeLog(gid, 'PSD plot upload',
-                                 filename=psd_series_plot_fname,
-                                 tag_name=['psd'], displayName=['PSDs'])
-
-            # upload source probabilities in json format and plot
-            if self.probabilities is not None:
-                gracedb.writeLog(gid, 'source probabilities JSON file upload',
-                                 filename=prob_fname, tag_name=['em_follow'])
-                logging.info('Uploaded source probabilities for event %s', gid)
-                gracedb.writeLog(gid, 'source probabilities plot upload',
-                                 filename=prob_plot_fname,
-                                 tag_name=['em_follow'])
-                logging.info('Uploaded source probabilities pie chart for '
-                             'event %s', gid)
-
         except Exception as exc:
             logging.error('Something failed during the upload/annotation of '
                           'event %s on GraceDB. The event may not have been '
                           'uploaded!', fname)
             logging.error(str(exc))
 
+        # plot the SNR timeseries and noise PSDs
+        if self.snr_series is not None:
+            if fname.endswith('.xml.gz'):
+                snr_series_fname = fname.replace('.xml.gz', '.hdf')
+            else:
+                snr_series_fname = fname.replace('.xml', '.hdf')
+            snr_series_plot_fname = snr_series_fname.replace('.hdf',
+                                                             '_snr.png')
+            asd_series_plot_fname = snr_series_fname.replace('.hdf',
+                                                             '_asd.png')
+            pl.figure()
+            ref_time = int(self.merger_time)
+            for ifo in sorted(self.snr_series):
+                curr_snrs = self.snr_series[ifo]
+                curr_snrs.save(snr_series_fname, group='%s/snr' % ifo)
+                pl.plot(curr_snrs.sample_times - ref_time, abs(curr_snrs),
+                        c=ifo_color(ifo), label=ifo)
+                if ifo in self.ifos:
+                    base = 'foreground/{}/'.format(ifo)
+                    snr = self.coinc_results[base + 'snr']
+                    mt = (self.coinc_results[base + 'end_time']
+                          + self.time_offset)
+                    pl.plot([mt - ref_time], [snr], c=ifo_color(ifo),
+                            marker='x')
+            pl.legend()
+            pl.xlabel('GPS time from {:d} (s)'.format(ref_time))
+            pl.ylabel('SNR')
+            pl.savefig(snr_series_plot_fname)
+            pl.close()
+
+            generate_asd_plot(self.psds, asd_series_plot_fname)
+
+            # Additionally save the PSDs into the snr_series file
+            for ifo in sorted(self.psds):
+                # Undo dynamic range factor
+                curr_psd = self.psds[ifo].astype(numpy.float64)
+                curr_psd /= pycbc.DYN_RANGE_FAC ** 2.0
+                curr_psd.save(snr_series_fname, group='%s/psd' % ifo)
+
+        if self.probabilities is not None:
+            prob_fname = fname.replace('.xml.gz', '_probs.json')
+            prob_plot_fname = prob_fname.replace('.json', '.png')
+
+            prob_plot = {k: v for (k, v) in self.probabilities.items()
+                         if v != 0.0}
+            labels, sizes = zip(*prob_plot.items())
+            colors = [source_color(label) for label in labels]
+            fig, ax = pl.subplots()
+            ax.pie(sizes, labels=labels, colors=colors, autopct='%1.1f%%',
+                   textprops={'fontsize': 15})
+            ax.axis('equal')
+            fig.savefig(prob_plot_fname)
+            pl.close()
+
+        # upload SNR series in HDF format and plots
+        if gid is not None and self.snr_series is not None:
+            try:
+                gracedb.writeLog(
+                    gid, 'SNR timeseries HDF file upload',
+                    filename=snr_series_fname
+                )
+                gracedb.writeLog(
+                    gid, 'SNR timeseries plot upload',
+                    filename=snr_series_plot_fname,
+                    tag_name=['background'],
+                    displayName=['SNR timeseries']
+                )
+                gracedb.writeLog(
+                    gid, 'ASD plot upload',
+                    filename=asd_series_plot_fname,
+                    tag_name=['psd'], displayName=['ASDs']
+                )
+            except Exception as exc:
+                logging.error('Failed to upload plots for %s', gid)
+                logging.error(str(exc))
+
+        # upload source probabilities in JSON format and plot
+        if gid is not None and self.probabilities is not None:
+            try:
+                gracedb.writeLog(
+                    gid, 'Source probabilities JSON file upload',
+                    filename=prob_fname, tag_name=['em_follow']
+                )
+                logging.info('Uploaded source probabilities for event %s', gid)
+                gracedb.writeLog(
+                    gid, 'Source probabilities plot upload',
+                    filename=prob_plot_fname,
+                    tag_name=['em_follow']
+                )
+                logging.info('Uploaded source probabilities pie chart for '
+                             'event %s', gid)
+            except Exception as exc:
+                logging.error(
+                    'Failed to upload source probability results for %s',
+                    gid
+                )
+                logging.error(str(exc))
+
         return gid
 
 def gracedb_tag_with_version(gracedb, event_id):
