@@ -17,7 +17,6 @@
 """
 Provides a class representing a time series.
 """
-from __future__ import division
 import os as _os, h5py
 from pycbc.types.array import Array, _convert, complex_same_precision_as, zeros
 from pycbc.types.array import _nocomplex
@@ -42,15 +41,6 @@ class TimeSeries(Array):
         Sample data type.
     copy : boolean, optional
         If True, samples are copied to a new array.
-
-    Attributes
-    ----------
-    delta_t
-    duration
-    start_time
-    end_time
-    sample_times
-    sample_rate
     """
 
     def __init__(self, initial_array, delta_t=None,
@@ -83,6 +73,20 @@ class TimeSeries(Array):
         self._delta_t = delta_t
         self._epoch = epoch
 
+    def to_astropy(self, name='pycbc'):
+        """ Return an astropy.timeseries.TimeSeries instance
+        """
+        from astropy.timeseries import TimeSeries as ATimeSeries
+        from astropy.time import Time
+        from astropy.units import s
+
+        start = Time(float(self.start_time), format='gps', scale='utc')
+        delta = self.delta_t * s
+        return ATimeSeries({name: self.numpy()},
+                           time_start=start,
+                           time_delta=delta,
+                           n_samples=len(self))
+
     def epoch_close(self, other):
         """ Check if the epoch is close enough to allow operations """
         dt = abs(float(self.start_time - other.start_time))
@@ -900,6 +904,7 @@ class TimeSeries(Array):
                            dtype=complex_same_precision_as(self)),
                            delta_f=delta_f)
         fft(tmp, f)
+        f._delta_f = delta_f
         return f
 
     def inject(self, other, copy=True):
