@@ -28,7 +28,6 @@ import os
 import logging
 
 from abc import (ABCMeta, abstractmethod)
-from six import add_metaclass
 
 from . import waveform
 from .waveform import (FailedWaveformError)
@@ -85,12 +84,6 @@ class BaseGenerator(object):
     current_params : dict
         A dictionary of the frozen keyword arguments and variable arguments
         that were last passed to the waveform generator.
-
-    Methods
-    -------
-    generate(variable_values)
-        Generates a waveform using the variable arguments and the frozen
-        arguments.
     """
     def __init__(self, generator, variable_args=(), record_failures=False,
                  **frozen_params):
@@ -184,16 +177,15 @@ class BaseGenerator(object):
 class BaseCBCGenerator(BaseGenerator):
     """Adds ability to convert from various derived parameters to parameters
     needed by the waveform generators.
-
-    Attributes
-    ----------
-    possible_args : set
-        The set of names of arguments that may be used in the `variable_args`
-        or `frozen_params`.
     """
+
     possible_args = set(parameters.td_waveform_params +
                         parameters.fd_waveform_params +
                         ['taper'])
+    """set: The set of names of arguments that may be used in the
+        `variable_args` or `frozen_params`.
+    """
+
     def __init__(self, generator, variable_args=(), **frozen_params):
         super(BaseCBCGenerator, self).__init__(generator,
             variable_args=variable_args, **frozen_params)
@@ -201,23 +193,19 @@ class BaseCBCGenerator(BaseGenerator):
         # parameters to those used by the waveform generation interface
         all_args = set(list(self.frozen_params.keys()) +
                        list(self.variable_args))
-        # compare a set of all args of the generator to the input parameters
-        # of the functions that do conversions and adds to list of pregenerate
-        # functions if it is needed
-        params_used, cs = transforms.get_common_cbc_transforms(
-                                       list(self.possible_args), variable_args)
-        for c in cs:
-            self._add_pregenerate(c)
         # check that there are no unused (non-calibration) parameters
         calib_args = set([a for a in self.variable_args if
                           a.startswith('calib_')])
         all_args = all_args - calib_args
-        unused_args = all_args.difference(params_used) \
-                              .difference(self.possible_args)
+        unused_args = all_args - self.possible_args
         if len(unused_args):
-            logging.warning("WARNING: The following args are not being used "
-                            "for waveform generation: %s",
-                            ', '.join(unused_args))
+            logging.warning("WARNING: The following parameters are generally "
+                            "not used by CBC waveform generators: %s. If you "
+                            "have provided a transform that converted these "
+                            "into known parameters (e.g., mchirp, q to "
+                            "mass1, mass2) or you are using a custom model "
+                            "that uses these parameters, you can safely "
+                            "ignore this message.", ', '.join(unused_args))
 
 
 class FDomainCBCGenerator(BaseCBCGenerator):
@@ -227,13 +215,6 @@ class FDomainCBCGenerator(BaseCBCGenerator):
     frequency- domain CBC waveforms in the radiation frame; i.e., with no
     detector response function applied. For more details, see `BaseGenerator`.
 
-    Derived parameters not understood by `get_fd_waveform` may be used as
-    variable args and/or frozen parameters, as long as they can be converted
-    into parameters that `get_fd_waveform` can use. For example, `mchirp` and
-    `eta` (currently, the only supported derived parameters) may be used as
-    variable/frozen params; these are converted to `mass1` and `mass2` prior to
-    calling the waveform generator function.
-
     Examples
     --------
     Initialize a generator:
@@ -247,26 +228,6 @@ class FDomainCBCGenerator(BaseCBCGenerator):
         (<pycbc.types.frequencyseries.FrequencySeries at 0x1110c1450>,
          <pycbc.types.frequencyseries.FrequencySeries at 0x1110c1510>)
 
-    Initialize a generator using mchirp, eta as the variable args, and generate
-    a waveform:
-
-    >>> generator = FDomainCBCGenerator(variable_args=['mchirp', 'eta'], delta_f=1./32, f_lower=30., approximant='TaylorF2')
-    >>> generator.generate(mchirp=1.5, eta=0.25)
-        (<pycbc.types.frequencyseries.FrequencySeries at 0x109a104d0>,
-         <pycbc.types.frequencyseries.FrequencySeries at 0x109a10b50>)
-
-    Note that the `current_params` contains the mchirp and eta values, along
-    with the mass1 and mass2 they were converted to:
-
-    >>> generator.current_params
-        {'approximant': 'TaylorF2',
-         'delta_f': 0.03125,
-         'eta': 0.25,
-         'f_lower': 30.0,
-         'mass1': 1.7230475324955525,
-         'mass2': 1.7230475324955525,
-         'mchirp': 1.5}
-
     """
     def __init__(self, variable_args=(), **frozen_params):
         super(FDomainCBCGenerator, self).__init__(waveform.get_fd_waveform,
@@ -295,13 +256,6 @@ class TDomainCBCGenerator(BaseCBCGenerator):
     domain CBC waveforms in the radiation frame; i.e., with no detector
     response function applied. For more details, see `BaseGenerator`.
 
-    Derived parameters not understood by `get_td_waveform` may be used as
-    variable args and/or frozen parameters, as long as they can be converted
-    into parameters that `get_td_waveform` can use. For example, `mchirp` and
-    `eta` (currently, the only supported derived parameters) may be used as
-    variable/frozen params; these are converted to `mass1` and `mass2` prior to
-    calling the waveform generator function.
-
     Examples
     --------
     Initialize a generator:
@@ -315,14 +269,6 @@ class TDomainCBCGenerator(BaseCBCGenerator):
         (<pycbc.types.timeseries.TimeSeries at 0x10e546710>,
          <pycbc.types.timeseries.TimeSeries at 0x115f37690>)
 
-    Initialize a generator using mchirp, eta as the variable args, and generate
-    a waveform:
-
-    >>> generator = TDomainCBCGenerator(variable_args=['mchirp', 'eta'], delta_t=1./4096, f_lower=30., approximant='TaylorT4')
-    >>> generator.generate(mchirp=1.75, eta=0.2)
-        (<pycbc.types.timeseries.TimeSeries at 0x116ac6050>,
-         <pycbc.types.timeseries.TimeSeries at 0x116ac6950>)
-
     """
     def __init__(self, variable_args=(), **frozen_params):
         super(TDomainCBCGenerator, self).__init__(waveform.get_td_waveform,
@@ -499,8 +445,7 @@ class TDomainSupernovaeGenerator(BaseGenerator):
 #
 
 
-@add_metaclass(ABCMeta)
-class BaseFDomainDetFrameGenerator(object):
+class BaseFDomainDetFrameGenerator(metaclass=ABCMeta):
     """Base generator for frquency-domain waveforms in a detector frame.
 
     Parameters
@@ -525,12 +470,6 @@ class BaseFDomainDetFrameGenerator(object):
         Keyword arguments setting the parameters that will not be changed from
         call-to-call of the generate function.
 
-    Attributes
-    ----------
-    location_args : set([])
-        Should be overriden by childern classes with a set of parameters
-        that set the binary's location.
-
     Attributes
     ----------
     detectors : dict
@@ -540,10 +479,6 @@ class BaseFDomainDetFrameGenerator(object):
     detector_names : list
         The list of detector names. If no detectors were provided, then this
         will be ['RF'] for "radiation frame".
-    epoch : lal.LIGOTimeGPS
-        The GPS start time of the frequency series returned by the generate function.
-        A time shift is applied to the waveform equal to tc-epoch. Update by using
-        ``set_epoch``.
     current_params : dict
         A dictionary of name, value pairs of the arguments that were last
         used by the generate function.
@@ -558,7 +493,11 @@ class BaseFDomainDetFrameGenerator(object):
         function.
 
     """
+
     location_args = set([])
+    """Set: Should be overriden by children classes with a set of parameters
+        that set the binary's location.
+    """
 
     def __init__(self, rFrameGeneratorClass, epoch, detectors=None,
                  variable_args=(), recalib=None, gates=None, **frozen_params):
@@ -608,6 +547,10 @@ class BaseFDomainDetFrameGenerator(object):
 
     @property
     def epoch(self):
+        """The GPS start time of the frequency series returned by the generate
+        function. A time shift is applied to the waveform equal to tc-epoch.
+        Update by using ``set_epoch``
+        """
         return _lal.LIGOTimeGPS(self._epoch)
 
     @abstractmethod
@@ -651,22 +594,6 @@ class FDomainDetFrameGenerator(BaseFDomainDetFrameGenerator):
         Keyword arguments setting the parameters that will not be changed from
         call-to-call of the generate function.
 
-    Attributes
-    ----------
-    location_args : set(['tc', 'ra', 'dec', 'polarization'])
-        The set of location parameters. These are not passed to the rFrame
-        generator class; instead, they are used to apply the detector response
-        function and/or shift the waveform in time. The parameters are:
-
-          * tc: The GPS time of coalescence (should be geocentric time).
-          * ra: Right ascension.
-          * dec: declination
-          * polarization: polarization.
-
-        All of these must be provided in either the variable args or the
-        frozen params if detectors is not None. If detectors
-        is None, tc may optionally be provided.
-
     Attributes
     ----------
     detectors : dict
@@ -707,7 +634,22 @@ class FDomainDetFrameGenerator(BaseFDomainDetFrameGenerator):
      'L1': <pycbc.types.frequencyseries.FrequencySeries at 0x116637a50>}
 
     """
+
     location_args = set(['tc', 'ra', 'dec', 'polarization'])
+    """set(['tc', 'ra', 'dec', 'polarization']):
+        The set of location parameters. These are not passed to the rFrame
+        generator class; instead, they are used to apply the detector response
+        function and/or shift the waveform in time. The parameters are:
+
+          * tc: The GPS time of coalescence (should be geocentric time).
+          * ra: Right ascension.
+          * dec: declination
+          * polarization: polarization.
+
+        All of these must be provided in either the variable args or the
+        frozen params if detectors is not None. If detectors
+        is None, tc may optionally be provided.
+    """
 
     def generate(self, **kwargs):
         """Generates a waveform, applies a time shift and the detector response
@@ -797,21 +739,6 @@ class FDomainDetFrameTwoPolGenerator(BaseFDomainDetFrameGenerator):
         Keyword arguments setting the parameters that will not be changed from
         call-to-call of the generate function.
 
-    Attributes
-    ----------
-    location_args : set(['tc', 'ra', 'dec'])
-        The set of location parameters. These are not passed to the rFrame
-        generator class; instead, they are used to apply the detector response
-        function and/or shift the waveform in time. The parameters are:
-
-          * tc: The GPS time of coalescence (should be geocentric time).
-          * ra: Right ascension.
-          * dec: declination
-
-        All of these must be provided in either the variable args or the
-        frozen params if detectors is not None. If detectors
-        is None, tc may optionally be provided.
-
     Attributes
     ----------
     detectors : dict
@@ -840,6 +767,19 @@ class FDomainDetFrameTwoPolGenerator(BaseFDomainDetFrameGenerator):
 
     """
     location_args = set(['tc', 'ra', 'dec'])
+    """ set(['tc', 'ra', 'dec']):
+        The set of location parameters. These are not passed to the rFrame
+        generator class; instead, they are used to apply the detector response
+        function and/or shift the waveform in time. The parameters are:
+
+          * tc: The GPS time of coalescence (should be geocentric time).
+          * ra: Right ascension.
+          * dec: declination
+
+        All of these must be provided in either the variable args or the
+        frozen params if detectors is not None. If detectors
+        is None, tc may optionally be provided.
+    """
 
     def generate(self, **kwargs):
         """Generates a waveform polarizations and applies a time shift.
@@ -943,21 +883,6 @@ class FDomainDetFrameModesGenerator(BaseFDomainDetFrameGenerator):
         Keyword arguments setting the parameters that will not be changed from
         call-to-call of the generate function.
 
-    Attributes
-    ----------
-    location_args : set(['tc', 'ra', 'dec'])
-        The set of location parameters. These are not passed to the rFrame
-        generator class; instead, they are used to apply the detector response
-        function and/or shift the waveform in time. The parameters are:
-
-          * tc: The GPS time of coalescence (should be geocentric time).
-          * ra: Right ascension.
-          * dec: declination
-
-        All of these must be provided in either the variable args or the
-        frozen params if detectors is not None. If detectors
-        is None, tc may optionally be provided.
-
     Attributes
     ----------
     detectors : dict
@@ -986,6 +911,19 @@ class FDomainDetFrameModesGenerator(BaseFDomainDetFrameGenerator):
 
     """
     location_args = set(['tc', 'ra', 'dec'])
+    """ set(['tc', 'ra', 'dec']):
+        The set of location parameters. These are not passed to the rFrame
+        generator class; instead, they are used to apply the detector response
+        function and/or shift the waveform in time. The parameters are:
+
+          * tc: The GPS time of coalescence (should be geocentric time).
+          * ra: Right ascension.
+          * dec: declination
+
+        All of these must be provided in either the variable args or the
+        frozen params if detectors is not None. If detectors
+        is None, tc may optionally be provided.
+    """
 
     def generate(self, **kwargs):
         """Generates and returns a waveform decompsed into separate modes.
