@@ -26,13 +26,10 @@ This module provides the worker functions and classes that are used when
 creating a workflow. For details about the workflow module see here:
 https://ldas-jobs.ligo.caltech.edu/~cbc/docs/pycbc/ahope.html
 """
-import sys, os, stat, subprocess, logging, math, string
-from six.moves import configparser as ConfigParser
-from six.moves import urllib
-from six.moves.urllib.request import pathname2url
-from six.moves.urllib.parse import urljoin
-from six.moves import cPickle
-import copy
+import os, stat, subprocess, logging, math, string, urllib, pickle, copy
+import configparser as ConfigParser
+from urllib.request import pathname2url
+from urllib.parse import urljoin
 import numpy, random
 from itertools import combinations, groupby, permutations
 from operator import attrgetter
@@ -44,9 +41,8 @@ from ligo import segments
 from ligo.lw import lsctables, ligolw
 from ligo.lw import utils as ligolw_utils
 from ligo.lw.utils import segments as ligolw_segments
-from ligo.lw.utils import process as ligolw_process
 from pycbc import makedir
-from pycbc.io.ligolw import LIGOLWContentHandler
+from pycbc.io.ligolw import LIGOLWContentHandler, create_process_table
 from . import pegasus_workflow
 from .configuration import WorkflowConfigParser, resolve_url
 from .pegasus_sites import make_catalog
@@ -102,8 +98,7 @@ class Executable(pegasus_workflow.Executable):
     # Sub classes, or instances, should override this. If not overriden the
     # file will be retained, but a warning given
     current_retention_level = KEEP_BUT_RAISE_WARNING
-    def __init__(self, cp, name,
-                 universe=None, ifos=None, out_dir=None, tags=None,
+    def __init__(self, cp, name, ifos=None, out_dir=None, tags=None,
                  reuse_executable=True, set_submit_subdir=True):
         """
         Initialize the Executable class.
@@ -137,7 +132,6 @@ class Executable(pegasus_workflow.Executable):
         else:
             self.ifo_string = None
         self.cp = cp
-        self.universe=universe
         self.name = name
         self.container_cls = None
         self.container_type = None
@@ -187,9 +181,10 @@ class Executable(pegasus_workflow.Executable):
 
         if exe_url.scheme in ['', 'file']:
             # NOTE: There could be a case where the exe is available at a
-            #       remote site, but not on the submit host. We could work to
-            #       allow this if it ever becomes a viable use-case. Some other
-            #       places (e.g. versioning) would have to be edited as well.
+            #       remote site, but not on the submit host. Currently allowed
+            #       for the OSG site, versioning will not work as planned if
+            #       we can't see the executable (can we perhaps run versioning
+            #       including singularity??)
 
             # Check that executables at file urls
             #  on the local site exist
@@ -197,6 +192,10 @@ class Executable(pegasus_workflow.Executable):
                 raise TypeError("Failed to find %s executable "
                                 "at %s on site %s" % (name, exe_path,
                                 exe_site))
+        elif exe_url.scheme == 'singularity':
+            # Will use an executable within a singularity container. Don't
+            # need to do anything here, as I cannot easily check it exists.
+            exe_path = exe_url.path
         else:
             # Could be http, gsiftp, etc. so it needs fetching if run now
             self.needs_fetching = True
@@ -218,14 +217,6 @@ class Executable(pegasus_workflow.Executable):
         logging.info("Using %s executable "
                      "at %s on site %s" % (name, exe_url.path, exe_site))
 
-        # Determine the condor universe if we aren't given one
-        if self.universe is None:
-            self.universe = 'vanilla'
-
-        if self.universe != 'vanilla':
-            logging.info("%s executable will run as %s universe"
-                         % (name, self.universe))
-
         # FIXME: This hasn't yet been ported to pegasus5 and won't work.
         #        Pegasus describes two ways to work with containers, and I need
         #        to figure out which is most appropriate and use that.
@@ -268,9 +259,6 @@ class Executable(pegasus_workflow.Executable):
             super(Executable, self).__init__(self.pegasus_name,
                                              installed=self.installed)
 
-        self._set_pegasus_profile_options()
-        self.set_universe(self.universe)
-
         if hasattr(self, "group_jobs"):
             self.add_profile('pegasus', 'clusters.size', self.group_jobs)
 
@@ -279,6 +267,10 @@ class Executable(pegasus_workflow.Executable):
             self.add_profile('pegasus', 'relative.submit.dir',
                              self.pegasus_name)
 
+        # Set configurations from the config file, these should override all
+        # other settings
+        self._set_pegasus_profile_options()
+
         self.execution_site = exe_site
         self.executable_url = exe_path
 
@@ -1605,14 +1597,14 @@ class FileList(list):
         Load a FileList from a pickle file
         """
         f = open(filename, 'r')
-        return cPickle.load(f)
+        return pickle.load(f)
 
     def dump(self, filename):
         """
         Output this FileList to a pickle file
         """
         f = open(filename, 'w')
-        cPickle.dump(self, f)
+        pickle.dump(self, f)
 
     def to_file_object(self, name, out_dir):
         """Dump to a pickle file and return an File object reference
@@ -1697,13 +1689,12 @@ class SegFile(File):
         """
         seglistdict = segments.segmentlistdict()
         seglistdict[ifo + ':' + name] = segmentlist
+        seg_summ_dict = None
         if seg_summ_list is not None:
             seg_summ_dict = segments.segmentlistdict()
             seg_summ_dict[ifo + ':' + name] = seg_summ_list
-        else:
-            seg_summ_dict = None
         return cls.from_segment_list_dict(description, seglistdict,
-                                          seg_summ_dict=None, **kwargs)
+                                          seg_summ_dict=seg_summ_dict, **kwargs)
 
     @classmethod
     def from_multi_segment_list(cls, description, segmentlists, names, ifos,
@@ -1898,7 +1889,7 @@ class SegFile(File):
         # create XML doc and add process table
         outdoc = ligolw.Document()
         outdoc.appendChild(ligolw.LIGO_LW())
-        process = ligolw_process.register_to_xmldoc(outdoc, sys.argv[0], {})
+        process = create_process_table(outdoc)
 
         for key, seglist in self.segment_dict.items():
             ifo, name = self.parse_segdict_key(key)
