@@ -25,13 +25,10 @@
 These are the unittests for noise generation
 """
 import unittest
-import numpy
 import pycbc.psd
-import sys
 from utils import simple_exit
 from pycbc.noise.reproduceable import noise_from_string
 from pycbc.fft.fftw import set_measure_level
-from hashlib import md5
 from pycbc.noise.reproduceable import normal
 set_measure_level(0)
 
@@ -48,10 +45,7 @@ class TestNoise(unittest.TestCase):
         # This just checks that the result hasn't changed. If it has
         # you should find out why
         summ = self.ts.sum()
-        if sys.version_info[0] < 3:
-            comp = 4.265258573533564e-18
-        else:
-            comp = 4.265258573533567e-18
+        comp = 4.265258573533567e-18
 
         diff = abs(summ - comp)
         self.assertTrue(diff < 1e-30)
